app

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 22, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute is the main entry point of the root and its children. It will create a new App struct and use it for the rest of the command.

Types

This section is empty.

Directories

Path Synopsis

Jump to